@@ -1,7 +1,6 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2019-2020 Mathieu Parent <math.parent@gmail.com>
+# Copyright (C) 2019-2021 Mathieu Parent <math.parent@gmail.com>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -19,14 +18,15 @@
 import logging
 from copy import deepcopy
 
-from gitlabracadabra.cache import GroupCache
-from gitlabracadabra.utils import access_level
+from gitlabracadabra.gitlab.access_levels import access_level
 
 
 logger = logging.getLogger(__name__)
 
 
 class GroupsMixin(object):
+    """Object with groups."""
+
     """_process_groups()
 
     Process the groups param.
@@ -50,19 +50,19 @@ class GroupsMixin(object):
             if 'group_full_path' not in group:
                 # Gitlab < 11.8
                 # https://gitlab.com/gitlab-org/gitlab-ce/merge_requests/24052
-                group['group_full_path'] = GroupCache.get_full_path_from_id(group['group_id'])
-            GroupCache.map_group(group['group_id'], group['group_full_path'])
+                group['group_full_path'] = self.connection.group_cache.full_path_from_id(group['group_id'])
+            self.connection.group_cache.map_group(group['group_id'], group['group_full_path'])
             if group['group_full_path'] in param_value.keys():
                 target_access_level = access_level(param_value[group['group_full_path']])
                 if group['group_access_level'] != target_access_level:
                     if dry_run:
                         logger.info('[%s] NOT Changing group %s access level: %s -> %s (dry-run)',
-                                     self._name, group['group_full_path'],
-                                     group['group_access_level'], target_access_level)
+                                    self._name, group['group_full_path'],
+                                    group['group_access_level'], target_access_level)
                     else:
                         logger.info('[%s] Changing group %s access level: %s -> %s',
-                                     self._name, group['group_full_path'],
-                                     group['group_access_level'], target_access_level)
+                                    self._name, group['group_full_path'],
+                                    group['group_access_level'], target_access_level)
                         self._obj.unshare(group['group_id'])
                         self._obj.share(group['group_id'], target_access_level)
                 param_value.pop(group['group_full_path'])
@@ -80,10 +80,10 @@ class GroupsMixin(object):
                                    self._name, group['group_full_path'], unknown_groups)
         # Remaining groups
         for group_full_path, target_group_access in sorted(param_value.items()):
-            group_id = GroupCache.get_id_from_full_path(group_full_path)
+            group_id = self.connection.group_cache.id_from_full_path(group_full_path)
             if group_id is None:
                 logger.warning('[%s] Group not found %s',
-                                self._name, group_full_path)
+                               self._name, group_full_path)
                 continue
             target_access_level = access_level(target_group_access)
             if dry_run:
