@@ -24,6 +24,8 @@ logger = logging.getLogger(__name__)
 
 
 class PipelineSchedulesMixin(object):
+    """Object with pipeline schedules."""
+
     """_process_pipeline_schedules()
 
     Process the pipeline_schedules param.
@@ -68,9 +70,9 @@ class PipelineSchedulesMixin(object):
                     if current_pipeline_schedule_param_value != target_pipeline_schedule_param_value:
                         if dry_run:
                             logger.info('[%s] NOT Changing pipeline schedule %s %s: %s -> %s (dry-run)',
-                                         self._name, current_pipeline_schedule_description,
-                                         target_pipeline_schedule_param_name, current_pipeline_schedule_param_value,
-                                         target_pipeline_schedule_param_value)
+                                        self._name, current_pipeline_schedule_description,
+                                        target_pipeline_schedule_param_name, current_pipeline_schedule_param_value,
+                                        target_pipeline_schedule_param_value)
                         else:
                             logger.info('[%s] Changing pipeline schedule %s %s: %s -> %s',
                                         self._name, current_pipeline_schedule_description,
@@ -84,24 +86,24 @@ class PipelineSchedulesMixin(object):
                 if unknown_pipeline_schedules in ['delete', 'remove']:
                     if dry_run:
                         logger.info('[%s] NOT Removing pipeline schedule %s (dry-run)',
-                                     self._name, current_pipeline_schedule_description)
+                                    self._name, current_pipeline_schedule_description)
                     else:
                         logger.info('[%s] Removing pipeline schedule %s',
-                                     self._name, current_pipeline_schedule_description)
+                                    self._name, current_pipeline_schedule_description)
                         current_pipeline_schedule.delete()
                 elif unknown_pipeline_schedules not in ['ignore', 'skip']:
                     logger.warning('[%s] NOT Removing pipeline schedule: %s',
-                                    self._name, current_pipeline_schedule_description)
+                                   self._name, current_pipeline_schedule_description)
         # Remaining pipeline_schedules
         for target_pipeline_schedule_name, target_pipeline_schedule in sorted(target_pipeline_schedules.items()):
             target_pipeline_schedule_variables = target_pipeline_schedule.pop('variables', [])
             unknown_variables = target_pipeline_schedule.pop('unknown_variables', unknown_pipeline_schedule_variables)
             if dry_run:
                 logger.info('[%s] NOT Adding pipeline schedule %s: %s -> %s (dry-run)',
-                             self._name, target_pipeline_schedule_name, None, target_pipeline_schedule)
+                            self._name, target_pipeline_schedule_name, None, target_pipeline_schedule)
             else:
                 logger.info('[%s] Adding pipeline schedule %s: %s -> %s',
-                             self._name, target_pipeline_schedule_name, None, target_pipeline_schedule)
+                            self._name, target_pipeline_schedule_name, None, target_pipeline_schedule)
                 pipeline_schedule = self._obj.pipelineschedules.create(target_pipeline_schedule)
                 self._handle_pipeline_schedule_variables(pipeline_schedule, target_pipeline_schedule_variables,
                                                          unknown_variables, dry_run)
@@ -135,12 +137,12 @@ class PipelineSchedulesMixin(object):
                     if current_variable_param_value != target_variable_param_value:
                         if dry_run:
                             logger.info('[%s] NOT Changing pipeline schedule variable %s %s: %s -> %s (dry-run)',
-                                         self._name, current_variable_key, target_variable_param_name,
-                                         current_variable_param_value, target_variable_param_value)
+                                        self._name, current_variable_key, target_variable_param_name,
+                                        current_variable_param_value, target_variable_param_value)
                         else:
                             logger.info('[%s] Changing pipeline schedule variable %s %s: %s -> %s',
-                                         self._name, current_variable_key, target_variable_param_name,
-                                         current_variable_param_value, target_variable_param_value)
+                                        self._name, current_variable_key, target_variable_param_name,
+                                        current_variable_param_value, target_variable_param_value)
                             new_data = {'key': current_variable_key,
                                         'value': target_variables[current_variable_key]['value']}
                             new_data[target_variable_param_name] = target_variable_param_value
@@ -150,20 +152,20 @@ class PipelineSchedulesMixin(object):
                 if unknown_variables in ['delete', 'remove']:
                     if dry_run:
                         logger.info('[%s] NOT Removing pipeline schedule variable %s (dry-run)',
-                                     self._name, current_variable_key)
+                                    self._name, current_variable_key)
                     else:
                         logger.info('[%s] Removing pipeline schedule variable %s',
-                                     self._name, current_variable_key)
+                                    self._name, current_variable_key)
                         pipeline_schedule.variables.delete(current_variable_key)
                 elif unknown_variables not in ['ignore', 'skip']:
                     logger.warning('[%s] NOT Removing variable: %s',
-                                    self._name, current_variable_key)
+                                   self._name, current_variable_key)
         # Remaining variables
         for target_variable_name, target_variable in sorted(target_variables.items()):
             if dry_run:
                 logger.info('[%s] NOT Adding pipeline schedule variable %s: %s -> %s (dry-run)',
-                             self._name, target_variable_name, None, target_variable)
+                            self._name, target_variable_name, None, target_variable)
             else:
                 logger.info('[%s] Adding pipeline schedule variable %s: %s -> %s',
-                             self._name, target_variable_name, None, target_variable)
+                            self._name, target_variable_name, None, target_variable)
                 pipeline_schedule.variables.create(target_variable)
