@@ -30,6 +30,7 @@ class GitLabracadabraGroup(GitLabracadabraObject, BoardsMixin, GroupsMixin, Labe
     EXAMPLE_YAML_HEADER = 'mygroup/:\n'
     DOC = [
         '# Group lifecycle',
+        'gitlab_id',
         'create_object',
         'delete_object',
 
@@ -82,6 +83,12 @@ class GitLabracadabraGroup(GitLabracadabraObject, BoardsMixin, GroupsMixin, Labe
         'type': 'object',
         'properties': {
             # Standard properties
+            'gitlab_id': {
+                'type': 'string',
+                'description': 'GitLab id',
+                '_example': 'gitlab',
+                '_doc_link': 'action_file.md#gitlab_id',
+            },
             'create_object': {
                 'type': 'boolean',
                 'description': 'Create object if it does not exists',
