@@ -15,17 +15,29 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+from __future__ import annotations
+
 import logging
 import re
 from copy import deepcopy
+from typing import TYPE_CHECKING, List, Optional
 
 from gitlab.exceptions import GitlabCreateError, GitlabDeleteError, GitlabGetError, GitlabListError, GitlabUpdateError
 
+from jsonschema.exceptions import ValidationError
 from jsonschema.validators import validator_for
 
-import gitlabracadabra.manager
+from gitlabracadabra.gitlab.connections import GitlabConnections
 
 
+if TYPE_CHECKING:
+    from pygit2 import UserPass
+
+    from gitlab import Gitlab
+
+    from gitlabracadabra.auth_info import AuthInfo
+    from gitlabracadabra.gitlab.connection import GitlabConnection
+
 logger = logging.getLogger(__name__)
 
 
@@ -41,14 +53,14 @@ class GitLabracadabraObject(object):
     }
 
     # If not None, use find(FIND_PARAM=...) instead of get(...)
-    FIND_PARAM = None
+    FIND_PARAM: Optional[str] = None
 
     # If not None, set to id of the object on create
-    CREATE_KEY = None
+    CREATE_KEY: Optional[str] = None
 
-    CREATE_PARAMS = []
+    CREATE_PARAMS: List[str] = []
 
-    IGNORED_PARAMS = []
+    IGNORED_PARAMS: List[str] = []
 
     def __init__(self, action_file, name, content):
         self._action_file = action_file
@@ -57,11 +69,28 @@ class GitLabracadabraObject(object):
         validator_class = validator_for(self.SCHEMA)
         validator_class.check_schema(self.SCHEMA)
         validator = validator_class(self.SCHEMA)
-        self._errors = sorted(validator.iter_errors(content), key=lambda e: e.path)
+        self._errors: list[ValidationError] = sorted(validator.iter_errors(content), key=lambda e: e.path)
+        self._gitlab_id = self._content.pop('gitlab_id', None)
         self._create_object = self._content.pop('create_object', None)
         self._delete_object = self._content.pop('delete_object', None)
 
-    def errors(self):
+    @property
+    def connection(self) -> GitlabConnection:
+        return GitlabConnections().get_connection(self._gitlab_id)
+
+    @property
+    def pygitlab(self) -> Gitlab:
+        return self.connection.pygitlab
+
+    @property
+    def pygit2_credentials(self) -> UserPass:
+        return self.connection.pygit2_credentials
+
+    @property
+    def registry_auth_info(self) -> AuthInfo:
+        return self.connection.registry_auth_info
+
+    def errors(self) -> list[ValidationError]:
         return self._errors
 
     """"type_name()
@@ -80,19 +109,12 @@ class GitLabracadabraObject(object):
     def _type_name_plural(cls):
         return cls._type_name() + 's'
 
-    """"_gitlab_manager()
-
-    Return the python-gitlab Gilab object.
-    """
-    def _gitlab_manager(self):
-        return gitlabracadabra.manager.get_manager()
-
     """"_object_manager()
 
     Return the python-gitlab Gilab object.
     """
     def _object_manager(self):
-        return getattr(self._gitlab_manager(), self._type_name_plural())
+        return getattr(self.pygitlab, self._type_name_plural())
 
     """"_create()
 
@@ -100,7 +122,7 @@ class GitLabracadabraObject(object):
     """
     def _create(self, dry_run=False):
         obj_manager = self._object_manager()
-        namespace_manager = self._gitlab_manager().namespaces
+        namespace_manager = self.pygitlab.namespaces
         namespaces = self._name.split('/')
         object_path = namespaces.pop()
         create_params = {
@@ -141,7 +163,7 @@ class GitLabracadabraObject(object):
     """
     def _delete(self, dry_run=False):
         if self._obj is None:
-            logger.info('[%s] NOT Deleting %s (not found)', self._name, self._type_name())
+            logger.debug('[%s] NOT Deleting %s (not found)', self._name, self._type_name())
         elif dry_run:
             logger.info('[%s] NOT Deleting %s (dry-run)', self._name, self._type_name())
         else:
@@ -178,22 +200,31 @@ class GitLabracadabraObject(object):
             return sorted(param_value)
         return param_value
 
+    """"_get_param()
+
+    Get a param value.
+    """
+    def _get_param(self, param_name):
+        return getattr(self._obj, param_name)
+
     """"_process_param()
 
     Process one param.
     """
     def _process_param(self, param_name, param_value, dry_run=False, skip_save=False):
-        if param_name in self.IGNORED_PARAMS:
+        if param_name in self.IGNORED_PARAMS and not skip_save:
             return
         target_value = self._canonalize_param(param_name, param_value)
         try:
             current_value = self._canonalize_param(param_name,
-                                                   self._unmangle_param(param_name, getattr(self._obj, param_name)))
+                                                   self._unmangle_param(param_name, self._get_param(param_name)))
         except AttributeError:
-            # FIXME Hidden attributes cannot be idempotent (i.e password)
-            logger.info('[%s] NOT Changing param %s: %s -> %s (current value is not available)',
-                        self._name, param_name, None, target_value)
-            return
+            if not skip_save:
+                # FIXME Hidden attributes cannot be idempotent (i.e password)
+                logger.info('[%s] NOT Changing param %s: %s -> %s (current value is not available)',
+                            self._name, param_name, None, target_value)
+                return
+            current_value = None
         if current_value != target_value:
             if 'dependencies' in self.SCHEMA and param_name in self.SCHEMA['dependencies']:
                 for dependency in self.SCHEMA['dependencies'][param_name]:
@@ -206,7 +237,7 @@ class GitLabracadabraObject(object):
             else:
                 logger.info('[%s] Changing param %s: %s -> %s',
                             self._name, param_name, current_value, target_value)
-                setattr(self._obj, param_name, target_value)
+                setattr(self._obj, param_name, self._mangle_param(param_name, target_value))
                 if not skip_save:
                     try:
                         self._obj.save()
@@ -296,7 +327,7 @@ class GitLabracadabraObject(object):
                     first_undocumented = False
                 cls.DOC.append(p)
         # Generate TOC
-        output += '# Table of Contents' + '\n\n'
+        output += '# Table of Contents <!-- omit in toc -->' + '\n\n'
         for doc in cls.DOC:
             if doc[0] == '#':
                 matches = re.match(r'^(#+) ?(.*)$', doc)
@@ -328,6 +359,8 @@ class GitLabracadabraObject(object):
                     example += '  ' + doc + ': My ' + doc.replace('_', ' ') + '\n'
                 output += '`' + doc + '` ' + properties[doc].get('description', 'Undocumented') + ':\n'
                 output += '```yaml\n' + example + '```\n\n'
+                if '_doc_link' in properties[doc]:
+                    output += 'More information can be found [here]({0})\n\n'.format(properties[doc]['_doc_link'])
             else:
                 output += '`' + doc + '` *Undocumented*.\n\n'
         return output
