@@ -27,6 +27,7 @@ from gitlabracadabra.mixins.labels import LabelsMixin
 from gitlabracadabra.mixins.members import MembersMixin
 from gitlabracadabra.mixins.milestones import MilestonesMixin
 from gitlabracadabra.mixins.mirrors import MirrorsMixin
+from gitlabracadabra.mixins.package_mirrors import PackageMirrorsMixin
 from gitlabracadabra.mixins.pipeline_schedules import PipelineSchedulesMixin
 from gitlabracadabra.mixins.rename_branches import RenameBranchesMixin
 from gitlabracadabra.mixins.variables import VariablesMixin
@@ -38,8 +39,8 @@ logger = logging.getLogger(__name__)
 
 
 class GitLabracadabraProject(GitLabracadabraObject, BoardsMixin, GroupsMixin, ImageMirrorsMixin, LabelsMixin,
-                             MembersMixin, MilestonesMixin, MirrorsMixin, PipelineSchedulesMixin, RenameBranchesMixin,
-                             VariablesMixin, WebhooksMixin):
+                             MembersMixin, MilestonesMixin, MirrorsMixin, PackageMirrorsMixin, PipelineSchedulesMixin,
+                             RenameBranchesMixin, VariablesMixin, WebhooksMixin):
     EXAMPLE_YAML_HEADER = 'mygroup/myproject:\n'
     DOC = [
         '# Project lifecycle',
@@ -169,6 +170,9 @@ class GitLabracadabraProject(GitLabracadabraObject, BoardsMixin, GroupsMixin, Im
         '# Mirroring container images',
         'image_mirrors',
 
+        '# Mirroring packages',
+        'package_mirrors',
+
         '# Deprecated',
         'issues_enabled',
         'merge_requests_enabled',
@@ -1136,6 +1140,144 @@ class GitLabracadabraProject(GitLabracadabraObject, BoardsMixin, GroupsMixin, Im
                              "      to: 'etcd:v3.4.1' # Default would be coreos/etcd:v3.4.1\n"),
                 '_doc_link': 'image_mirrors.md',
             },
+            # GitLabracadabra
+            'package_mirrors': {
+                'type': 'array',
+                'description': 'Package image mirrors',
+                'items': {
+                    'oneOf': [
+                        {
+                            'type': 'object',
+                            'description': 'Raw source',
+                            'properties': {
+                                'raw': {
+                                    'type': 'object',
+                                    'properties': {
+                                        'default_url': {
+                                            'type': 'string',
+                                        },
+                                        'default_package_name': {
+                                            'type': 'string',
+                                        },
+                                        'default_package_version': {
+                                            'type': 'string',
+                                        },
+                                        'package_files': {
+                                            'type': 'array',
+                                            'items': {
+                                                'type': 'object',
+                                                'properties': {
+                                                    'url': {
+                                                        'type': 'string',
+                                                    },
+                                                    'package_name': {
+                                                        'type': 'string',
+                                                    },
+                                                    'package_version': {
+                                                        'type': 'string',
+                                                    },
+                                                    'file_name': {
+                                                        'type': 'string',
+                                                    },
+                                                },
+                                                'additionalProperties': False,
+                                            },
+                                        },
+                                    },
+                                    'required': ['default_url'],
+                                    'additionalProperties': False,
+                                },
+                            },
+                            'additionalProperties': False,
+                        },
+                        {
+                            'type': 'object',
+                            'description': 'Github source',
+                            'properties': {
+                                'github': {
+                                    'type': 'object',
+                                    'properties': {
+                                        'full_name': {
+                                            'type': 'string',
+                                        },
+                                        'package_name': {
+                                            'type': 'string',
+                                        },
+                                        'tags': {
+                                            'type': 'array',
+                                            'items': {
+                                                'type': 'string',
+                                            },
+                                        },
+                                        'semver': {
+                                            'type': 'string',
+                                        },
+                                        'latest_release': {
+                                            'type': 'boolean',
+                                        },
+                                        'tarball': {
+                                            'type': 'boolean',
+                                        },
+                                        'zipball': {
+                                            'type': 'boolean',
+                                        },
+                                        'assets': {
+                                            'type': 'array',
+                                            'items': {
+                                                'type': 'string',
+                                            },
+                                        },
+                                    },
+                                    'required': ['full_name'],
+                                    'additionalProperties': False,
+                                },
+                            },
+                            'additionalProperties': False,
+                        },
+                        {
+                            'type': 'object',
+                            'description': 'Helm source',
+                            'properties': {
+                                'helm': {
+                                    'type': 'object',
+                                    'properties': {
+                                        'repo_url': {
+                                            'type': 'string',
+                                        },
+                                        'package_name': {
+                                            'type': 'string',
+                                        },
+                                        'versions': {
+                                            'type': 'array',
+                                            'items': {
+                                                'type': 'string',
+                                            },
+                                        },
+                                        'semver': {
+                                            'type': 'string',
+                                        },
+                                        'limit': {
+                                            'type': 'integer',
+                                        },
+                                        'channel': {
+                                            'type': 'string',
+                                        },
+                                    },
+                                    'required': ['repo_url', 'package_name'],
+                                    'additionalProperties': False,
+                                },
+                            },
+                            'additionalProperties': False,
+                        },
+                    ],
+                },
+                '_example': ('\n'
+                             '    - raw:\n'
+                             '        default_url: https://download.docker.com/linux/debian/gpg\n'
+                             '        default_package_name: docker\n'
+                             "        default_package_version: '0'\n"),
+                '_doc_link': 'package_mirrors.md',
+            },
             # From https://docs.gitlab.com/ee/api/projects.html#edit-project
             'issues_enabled': {
                 'type': 'boolean',
