@@ -16,30 +16,17 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-from unittest import TestCase, skipIf
-try:
-    from unittest.mock import patch
-except ImportError:
-    from mock import patch  # Python 2
+from unittest import skipIf
 
-from gitlab import Gitlab, __version__ as gitlab_version
+from gitlab import __version__ as gitlab_version
 
-import gitlabracadabra.manager
 from gitlabracadabra.objects.group import GitLabracadabraGroup
 from gitlabracadabra.objects.user import GitLabracadabraUser
-from gitlabracadabra.tests.utils import my_vcr
+from gitlabracadabra.tests import my_vcr, patch
+from gitlabracadabra.tests.case import TestCaseWithManager
 
 
-class TestGroup(TestCase):
-    def setUp(self):
-        gitlabracadabra.manager._gitlab = Gitlab(  # noqa: S106
-            'http://localhost:3000',
-            private_token='oQ9_zgPgaqyyvW1GrnQY',
-        )
-
-    def tearDown(self):
-        gitlabracadabra.manager._gitlab = None
-
+class TestGroup(TestCaseWithManager):
     @my_vcr.use_cassette
     def test_no_create(self, cass):
         obj = GitLabracadabraGroup('memory', 'test/no_create_group', {})
@@ -164,8 +151,8 @@ class TestGroup(TestCase):
             obj.process()
             self.assertTrue(cass.all_played)
             logger.warning.assert_called_once_with('[%s] Group not found %s',
-                                                           'test/group_of_groups3',
-                                                           'test/group_not_found')
+                                                   'test/group_of_groups3',
+                                                   'test/group_not_found')
 
     # https://github.com/python-gitlab/python-gitlab/pull/1139
     @skipIf(gitlab_version in ['1.6.0', '2.4.0'], 'python-gitlab without share group with groups')
