@@ -16,12 +16,11 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-from unittest import TestCase
-
 from gitlabracadabra.objects.group import GitLabracadabraGroup
 from gitlabracadabra.objects.project import GitLabracadabraProject
 from gitlabracadabra.parser import GitlabracadabraParser
-from gitlabracadabra.tests.utils import patch_open
+from gitlabracadabra.tests import patch_open
+from gitlabracadabra.tests.case import TestCase
 
 
 class TestParser(TestCase):
@@ -133,6 +132,17 @@ class TestParser(TestCase):
         self.assertIn('another-key', d)
         self.assertEqual(d['another-key'], {'param4': 'value4'})
 
+    def test_extend_not_found(self):
+        p = GitlabracadabraParser.from_yaml('-', """
+            key2:
+              extends:
+                - key1
+            """)
+        with self.assertRaises(ValueError) as cm:
+            {k: v for k, v in p._items()}
+
+        self.assertEqual(str(cm.exception), '- (`key1` from `key2`): key1 not found')
+
     def test_extend_recursion(self):
         p = GitlabracadabraParser.from_yaml('-', """
             key1:
