@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
 # Copyright (C) 2019-2020 Mathieu Parent <math.parent@gmail.com>
@@ -16,25 +15,12 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-from unittest import TestCase
-
-from gitlab import Gitlab
-
-import gitlabracadabra.manager
 from gitlabracadabra.objects.user import GitLabracadabraUser
-from gitlabracadabra.tests.utils import my_vcr
+from gitlabracadabra.tests import my_vcr
+from gitlabracadabra.tests.case import TestCaseWithManager
 
 
-class TestUser(TestCase):
-    def setUp(self):
-        gitlabracadabra.manager._gitlab = Gitlab(  # noqa: S106
-            'http://localhost',
-            private_token='DKkdC5JmKWWZgXZGzg83',
-        )
-
-    def tearDown(self):
-        gitlabracadabra.manager._gitlab = None
-
+class TestUser(TestCaseWithManager):
     @my_vcr.use_cassette
     def test_no_create(self, cass):
         obj = GitLabracadabraUser('memory', 'no_create_user', {})
@@ -65,32 +51,39 @@ class TestUser(TestCase):
         self.assertTrue(cass.all_played)
 
     @my_vcr.use_cassette
-    def notest_simple_parameters(self, cass):
-        obj = GitLabracadabraUser('memory', 'test/user_simple_parameters', {
+    def test_simple_parameters(self, cass):
+        obj = GitLabracadabraUser('memory', 'user_simple_parameters', {
             'name': 'user-with-simple-parameters',
-            'description': 'user with simple parameters',
-            'visibility': 'public',
-            'lfs_enabled': False,
-            'request_access_enabled': True,
-            # 'shared_runners_minutes_limit': 42,  # EE, admin-only
+            'email': 'user-with-simple-parameters@example.org',
+            'skip_confirmation': True,
+            'skip_reconfirmation': True,
+            'public_email': 'contact@example.org',
+            'password': 'P@ss12345678',
+            # 'reset_password'
+            'projects_limit': 42,
+            'can_create_group': False,
+            'admin': True,
+            'external': True,
+            'shared_runners_minutes_limit': 42,
+            'extra_shared_runners_minutes_limit': 42,
+            # 'avatar'
+            'skype': '12345',
+            'linkedin': 'linked_in',
+            'twitter': 't_w_i_t_t_e_r',
+            'website_url': 'https://example.org',
+            'location': 'Nowhere',
+            'organization': 'My Corp',
+            'bio': 'Not much',
+            'private_profile': True,
+            'note': 'Fake account?',
+            'extern_uid': '12345678',
+            'provider': 'github',
+            # 'color_scheme_id'
+            # 'theme_id'
+            # 'force_random_password'
+            # 'group_id_for_saml'
+            # 'view_diffs_file_by_file'
         })
+        self.assertEqual(obj.errors(), [])
         obj.process()
         self.assertTrue(cass.all_played)
-
-    @my_vcr.use_cassette
-    def test_get_id_from_username(self, cass):
-        # Clean up
-        GitLabracadabraUser._USERS_USERNAME2ID = {}
-        GitLabracadabraUser._USERS_ID2USERNAME = {}
-        ret = GitLabracadabraUser.get_id_from_username('user_mapping')
-        self.assertEqual(ret, 9)
-        self.assertTrue(cass.all_played)
-
-    @my_vcr.use_cassette
-    def test_get_username_from_id(self, cass):
-        # Clean up
-        GitLabracadabraUser._USERS_USERNAME2ID = {}
-        GitLabracadabraUser._USERS_ID2USERNAME = {}
-        ret = GitLabracadabraUser.get_username_from_id(9)
-        self.assertEqual(ret, 'user_mapping')
-        self.assertTrue(cass.all_played)
